"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getModifiers = exports.Modifier = void 0;
var Modifier;
(function (Modifier) {
    Modifier[Modifier["class"] = 0] = "class";
    Modifier[Modifier["interface"] = 1] = "interface";
    Modifier[Modifier["enum"] = 2] = "enum";
    Modifier[Modifier["static"] = 3] = "static";
    Modifier[Modifier["public"] = 4] = "public";
    Modifier[Modifier["private"] = 5] = "private";
    Modifier[Modifier["protected"] = 6] = "protected";
    Modifier[Modifier["abstract"] = 7] = "abstract";
    Modifier[Modifier["final"] = 8] = "final";
    Modifier[Modifier["super"] = 9] = "super";
    Modifier[Modifier["annotation"] = 10] = "annotation";
})(Modifier = exports.Modifier || (exports.Modifier = {}));
/**
 * Extracts modifiers from a string (only if they are at the beginning).
 * @param input String that starts with modifiers / already split string
 * @returns all modifiers as modifiers and the new string (without modifiers)
 */
function getModifiers(input) {
    const modifiers = new Set();
    const modifiedStringArray = (typeof input !== 'string' ? input : input.split(' ')).filter((value) => !value.match(/^\s*$/));
    let candidate = modifiedStringArray.at(0);
    let flag = candidate ? Modifier[candidate] : undefined;
    while (flag !== undefined && candidate) {
        modifiers.add(flag);
        modifiedStringArray.shift();
        candidate = modifiedStringArray.at(0);
        flag = candidate ? Modifier[candidate] : undefined;
    }
    return {
        modifiers: [...modifiers],
        newString: modifiedStringArray.join(' '),
    };
}
exports.getModifiers = getModifiers;
